﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Analysis.FitnessLandscape.Algorithms;
using HeuristicLab.Collections;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Operators;
using HeuristicLab.Optimization;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;
using HeuristicLab.PluginInfrastructure;
namespace HeuristicLab.Analysis.FitnessLandscape {

  [Item("RepeatMultiAnalyzer", "A collection of analyzers for consolidating repeats.")]
  [StorableClass]
  public class RepeatMultiAnalyzer : CheckedMultiOperator<IRepeatsAnalyzer>, IAnalyzer {
    public bool EnabledByDefault {
      get { return false; }
    }

    public override bool CanChangeName {
      get { return false; }
    }

    [StorableConstructor]
    protected RepeatMultiAnalyzer(bool deserializing) : base(deserializing) { }
    protected RepeatMultiAnalyzer(RepeatMultiAnalyzer original, Cloner cloner) : base(original, cloner) { }

    public RepeatMultiAnalyzer()
      : base() {

      foreach (var analyzer in ApplicationManager.Manager.GetInstances<IRepeatsAnalyzer>())
        Operators.Add(analyzer);

    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new RepeatMultiAnalyzer(this, cloner);
    }

    public override IOperation InstrumentedApply() {
      OperationCollection next = new OperationCollection();
      foreach (IndexedItem<IRepeatsAnalyzer> item in Operators.CheckedItems)
        next.Add(ExecutionContext.CreateOperation(item.Value));
      next.Add(base.InstrumentedApply());
      return next;
    }
  }
}
